@@ -17,7 +17,7 @@
 #' @param tName - character string with name of the tcoord in the 'ERDDAP' dataset (default "time")
 #' @param verbose - logical variable (default FALSE) if the the URL request should be verbose
 #' @param cache_remove - logical variable (default TRUE) whether to delete 'rerddap' cache
-#' @return structure with data and dimensions
+#' @return If successful a structure with data and dimensions
 #' \itemize{
 #'   \item extract$data - the masked data array dimensioned (lon,lat,time)
 #'   \item extract$varname - the name of the parameter extracted
@@ -26,6 +26,7 @@
 #'   \item extract$latitude - the latitudes always going south to north
 #'   \item extract$time - the times of the extracts
 #'   }
+#'   else an error string
 #' @examples
 #' # toy example to show use
 #' # and keep execution time low
@@ -69,18 +70,18 @@ rxtractogon <- function(dataInfo, parameter, xcoord = NULL, ycoord = NULL,
   rerddap::cache_setup(temp_dir = TRUE)
   if (!(methods::is(dataInfo, "info"))) {
     print("error - dataInfo is not a valid info structure from rerddap")
-    return()
+    return("bad info structure")
   }
 
   #  check that the dataset is a grid
   if (!("Grid" %in% dataInfo$alldata$NC_GLOBAL$value)) {
     print("error - dataset is not a Grid")
-    return()
+    return("dataset not a grid")
   }
 
 if (length(xcoord) != length(ycoord)) {
   print('xcoord and ycoord are not of the same length')
-  stop('program stops')
+  return('bad xcoord,  ycoord values')
 }
 
 #extend out tpos to be length 2 if not
@@ -99,6 +100,11 @@ extract <-  rxtracto_3D(dataInfo, parameter = parameter, xcoord = xcoord1,
                         xName = xName, yName = yName, zName = zName,
                         verbose = verbose, cache_remove = cache_remove)
 #	extract <- xtracto_3D(xcoord1,ycoord1,tpos1,dtype, verbose)
+if (!is.list(extract)) {
+  print('error in call to rxtracto_3D')
+  print('see messages above')
+  return("rxtracto_3D error")
+}
 if (length(dim(extract[[1]])) == 2) {
    extract[[1]] <- array(extract[[1]], c(dim(extract[[1]]), 1))
   }
